==> jmb.core-1.0.2.tar.gz: jmb.core-1.0.2/jmb/core/management/commands/jmbcollect.py <==
# coding: utf-8
"""
.. _jmbcollect:

jmbcollect
==========

Command to collect info to deploy using bower.

scenario
--------

Each app may depend on a series of *external* libraries (eg.: jquery,
bootstrap, jcrop) that are normally included in the app distribution (under
``/static`` folder) with the result that:

* may be repeated several times in the project assets
* may not be concatenated to gain better performance
* may not be updated on a project base

This command aims at delegating to bower the management of these
dependencies so that they can be handled with the same mechanism
we use for external resources of the project.

Also *internal* resources (css end js) may be declared so that they can
be concatenated by gulp asset management.

setup
------

Each app must declare a dict named ``DEPENDENCIES`` that is
a dict with 2 keys and we place it in the ``__init__`` of
the project. It's content is better explained by a single example::

  DEPENDENCIES = {
      'EXTERNAL': {
          "fileapi": "~2.0.18",
          "underscore": "^1.8.3",
          "font-awesome": "fontawesome#^4.5.0",
          "Jcrop": "jcrop#^2.0.4"
      },
      'INTERNAL': {
          'js': [
              ('imagefileinput/imagefileinput.js', 'imagefileinput.js'),
              ('imagefileinput/FileAPI/FileAPI.exif.js', 'FileAPI.exif.js'),
          ],
          'css': [
              'style.css',
              ('imagefileinput/imagefileinput.css', 'imagefileinput.css'),
          ],
      },
  }

the ``INTERNAL`` key is a dict with 2 more keys, ``js`` and ``css`` that are lists
of files to be copied from static to <static>/apps/app_package. In case you want to
change the position in the destination you can use a tuple as above. See ``css`` for
an example of the two possibilities.

usage::

  dj jmbcollect

:-c: add debugging on console
:-l: debug_level
"""

from __future__ import unicode_literals

import os
import sys
import json
import shutil
import importlib
import logging
try:
    from logutils.colorize import ColorizingStreamHandler as StreamHandler
except ImportError:
    from logging import StreamHandler

from django.core.management.base import BaseCommand
from django.conf import settings

from optparse import make_option
try:
    from web.settings import deps_override
except:
    deps_override = None


logger = logging.getLogger('jmb')

class Command(BaseCommand):

    """Get all messages from configured Host
    """
    help = "Add external libraries to bower components and integrate internal scripts/css"

    def add_arguments(self, parser):
        # -c enables logging using store_true
        parser.add_argument('-c', '--console', action='store_true', default=False,
                    help='Debug - write logging to console')
        parser.add_argument('-l', '--debug-level', default='info',
                    help='Set debug level (debug, info, warnings) for console', )

    output_transaction = True

    def handle(self, *args, **options):

        if not deps_override:
            print("No file deps_overwrite found")
            sys.exit()

        level = getattr(logging,  options.get('debug_level').upper())
        if options.get('console'):
            console_handler = StreamHandler()
            console_handler.setLevel(level)
            logger.addHandler(console_handler)
            logger.setLevel(level)
        deps = self.collect()
        # insert_lines('dependencies',
        #              self.get_external(deps),
        #              'bower.json'
        #              )
        self.get_internal(deps)

    def collect(self):
        deps = deps_override.OVERRIDES

        for app in settings.INSTALLED_APPS:
            logger.debug(app)
            if app not in deps:
                mod = importlib.import_module(app)
                logger.debug("mod: %r" % mod)

                try:
                    deps[app] = mod.DEPENDENCIES
                    logger.debug("Found: %r" % mod.DEPENDENCIES)
                except AttributeError:
                    pass
        return deps

    def get_external(self, deps):
        """Return the lines we want to insert into bower.json
        Check if file is already requested
        """
        bower = json.load(open('bower.json'))
        res = {}
        for info in deps.values():
            res.update(info['EXTERNAL'])
        bower_insert = []
        for key, value in res.iteritems():
            if key not in bower['dependencies']:
                bower_insert += ['    "{}": "{}",\n'.format(key, value)]
        return bower_insert

    def get_internal(self, deps):
        """Return the list of tuple: (src, dest) we want to add to static/apps

        eg::
          deps = {
             'fileapi': {
                 'css': ['imagefileinput/imagefileinput.css',]
                 'js':  ['imagefileinput/imagefileinput.js',]
              }
          }
        """
        res = []
        static = settings.STATICFILES_DIRS[0]
        for app, info in deps.iteritems():
            if app in settings.INSTALLED_APPS:
                mod = importlib.import_module(app)
                dir = os.path.dirname(mod.__file__)
                for key in ('css', 'js'):
                    if 'INTERNAL' in info and key in info['INTERNAL']:
                        for src in info['INTERNAL'][key]:
                            if isinstance(src,  (tuple, list)):
                                dest = src[1]
                                src = src[0]
                            else:
                                dest = src
                            res += [('{dir}/static/{src}'.format(**locals()),
                                     '{static}/apps/{app}/{key}/{dest}'.format(**locals()))]
        for src, dest in res:
            if not os.path.exists(os.path.dirname(dest)):
                logger.info("mkdirs {}".format(os.path.dirname(dest)))
                os.makedirs(os.path.dirname(dest))
            logger.info("==> {}".format('<static>' + dest.replace(static, '')))
            shutil.copy(src, dest)

def insert_lines(start, new_lines, file_name):
    """Substitute all occurencies of old_string with new string
    in file matching file_pattern

    :param start: string that identifies the line after which we insert
    :param new_lines: the lines to be added
    :param file_name: the file name we are modifying
    """
    filepath = os.path.join(settings.BASE_DIR, file_name)
    if os.path.isfile(filepath):
        content = []
        with open(filepath, 'r') as f:
            for line in f:
                content += [line]
                if start in line:
                    content += new_lines

        with open(filepath, 'w') as f:
            f.write("".join(content))

==> jmb.core-1.0.9.1.tar.gz: jmb.core-1.0.9.1/jmb/core/management/commands/jmbcollect.py <==
# coding: utf-8
"""
.. _jmbcollect:

jmbcollect
==========

Command to collect info to deploy using bower.

scenario
--------

Each app may depend on a series of *external* libraries (eg.: jquery,
bootstrap, jcrop) that are normally included in the app distribution (under
``/static`` folder) with the result that:

* may be repeated several times in the project assets
* may not be concatenated to gain better performance
* may not be updated on a project base

This command aims at delegating to bower the management of these
dependencies so that they can be handled with the same mechanism
we use for external resources of the project.

Also *internal* resources (css end js) may be declared so that they can
be concatenated by gulp asset management.

setup
------

Each app must declare a dict named ``DEPENDENCIES`` that is
a dict with 2 keys and we place it in the ``__init__`` of
the project. It's content is better explained by a single example::

  DEPENDENCIES = {
      'EXTERNAL': {
          "fileapi": "~2.0.18",
          "underscore": "^1.8.3",
          "font-awesome": "fontawesome#^4.5.0",
          "Jcrop": "jcrop#^2.0.4"
      },
      'INTERNAL': {
          'js': [
              ('imagefileinput/imagefileinput.js', 'imagefileinput.js'),
              ('imagefileinput/FileAPI/FileAPI.exif.js', 'FileAPI.exif.js'),
          ],
          'css': [
              'style.css',
              ('imagefileinput/imagefileinput.css', 'imagefileinput.css'),
          ],
      },
  }

the ``INTERNAL`` key is a dict with 2 more keys, ``js`` and ``css`` that are lists
of files to be copied from static to <static>/apps/app_package. In case you want to
change the position in the destination you can use a tuple as above. See ``css`` for
an example of the two possibilities.

usage::

  dj jmbcollect

:-c: add debugging on console
:-l: debug_level
"""

from __future__ import unicode_literals

import os
import sys
import json
import shutil
import importlib
import logging
try:
    from logutils.colorize import ColorizingStreamHandler as StreamHandler
except ImportError:
    from logging import StreamHandler

from django.core.management.base import BaseCommand
from django.conf import settings

from optparse import make_option
try:
    from web.settings import deps_override
except:
    deps_override = None


logger = logging.getLogger('jmb')

class Command(BaseCommand):

    """Get all messages from configured Host
    """
    help = "Add external libraries to bower components and integrate internal scripts/css"

    def add_arguments(self, parser):
        # -c enables logging using store_true
        parser.add_argument('-c', '--console', action='store_true', default=False,
                    help='Debug - write logging to console')
        parser.add_argument('-l', '--debug-level', default='info',
                    help='Set debug level (debug, info, warnings) for console', )

    output_transaction = True

    def handle(self, *args, **options):

        if not deps_override:
            print("No file deps_overwrite found")
            sys.exit()

        level = getattr(logging,  options.get('debug_level').upper())
        if options.get('console'):
            console_handler = StreamHandler()
            console_handler.setLevel(level)
            logger.addHandler(console_handler)
            logger.setLevel(level)
        deps = self.collect()
        # insert_lines('dependencies',
        #              self.get_external(deps),
        #              'bower.json'
        #              )
        self.get_internal(deps)

    def collect(self):
        deps = deps_override.OVERRIDES

        for app in settings.INSTALLED_APPS:
            logger.debug(app)
            if app not in deps:
                mod = importlib.import_module(app)
                logger.debug("mod: %r" % mod)

                try:
                    deps[app] = mod.DEPENDENCIES
                    logger.debug("Found: %r" % mod.DEPENDENCIES)
                except AttributeError:
                    pass
        return deps

    def get_external(self, deps):
        """Return the lines we want to insert into bower.json
        Check if file is already requested
        """
        bower = json.load(open('bower.json'))
        res = {}
        for info in deps.values():
            res.update(info['EXTERNAL'])
        bower_insert = []
        for key, value in res.items():
            if key not in bower['dependencies']:
                bower_insert += ['    "{}": "{}",\n'.format(key, value)]
        return bower_insert

    def get_internal(self, deps):
        """Return the list of tuple: (src, dest) we want to add to static/apps

        eg::
          deps = {
             'fileapi': {
                 'css': ['imagefileinput/imagefileinput.css',]
                 'js':  ['imagefileinput/imagefileinput.js',]
              }
          }
        """
        res = []
        static = settings.STATICFILES_DIRS[0]
        for app, info in deps.items():
            if app in settings.INSTALLED_APPS:
                mod = importlib.import_module(app)
                dir = os.path.dirname(mod.__file__)
                for key in ('css', 'js'):
                    if 'INTERNAL' in info and key in info['INTERNAL']:
                        for src in info['INTERNAL'][key]:
                            if isinstance(src,  (tuple, list)):
                                dest = src[1]
                                src = src[0]
                            else:
                                dest = src
                            res += [('{dir}/static/{src}'.format(**locals()),
                                     '{static}/apps/{app}/{key}/{dest}'.format(**locals()))]
        for src, dest in res:
            if not os.path.exists(os.path.dirname(dest)):
                logger.info("mkdirs {}".format(os.path.dirname(dest)))
                os.makedirs(os.path.dirname(dest))
            logger.info("==> {}".format('<static>' + dest.replace(static, '')))
            shutil.copy(src, dest)

def insert_lines(start, new_lines, file_name):
    """Substitute all occurencies of old_string with new string
    in file matching file_pattern

    :param start: string that identifies the line after which we insert
    :param new_lines: the lines to be added
    :param file_name: the file name we are modifying
    """
    filepath = os.path.join(settings.BASE_DIR, file_name)
    if os.path.isfile(filepath):
        content = []
        with open(filepath, 'r') as f:
            for line in f:
                content += [line]
                if start in line:
                    content += new_lines

        with open(filepath, 'w') as f:
            f.write("".join(content))
